==> jffnms_0.7.8.orig.tar.gz: jffnms-0.7.8/htdocs/admin/adm/adm_interfaces.php <==
<? 
    $clean_url_del_vars=Array("bulk_add_ids","bulk_add");
    include ("../../auth.php");
    
    if (!profile("ADMIN_HOSTS")) die ("<H1> You dont have Permission to access this page.</H1></HTML>");

    adm_header("Interfaces");
?>
<SCRIPT>
function check(field_aux) {
    field=document.forms[0].elements[field_aux];
    for (i = 0; i < field.length; i++) { 
	if (field[i].checked==true) field[i].checked = false; 
	else	field[i].checked = true; 
    }
    return true;
}
</SCRIPT>
<?
    unset($old_action);


    function show_header($fields,$sample_data = array(),$number_of_showable_fields = 0) {
    
	std_table_row();

	if (is_array($fields))
	foreach ($fields as $field_name=>$data) 
	    if ($data["showable"] > 0)
		switch ($field_name) {
		    case "action" :
			if (is_numeric($GLOBALS["type_id"]))
			    adm_table_header_cell("<font size=-2>".linktext("View all Types",$GLOBALS["REQUEST_URI"]."&type_id=&action=")."</font>","center",2);
			else
			    adm_table_header_cell("<font size=-2>".linktext($sample_data["type_description"],$GLOBALS["REQUEST_URI"]."&action=&type_id=".$sample_data["type"])."</font>","center",2);
		        break;
    		    case "row_filler":
			$rows = $data["max"]-$number_of_showable_fields;
			if ($rows > 0)
			    adm_table_header_cell("&nbsp;","center",$rows);
			break;
		    default: 
			adm_table_header_cell($data["description"],"center");
		}

	adm_table_row_close();
    }

    function show_values ($fields,$values,$edit = 0, $ids = array(),$cant = 1, $number_of_showable_fields = 0) {
    
	if (is_array($fields))
	foreach ($fields as $field_name=>$data) if ($data["showable"] > 0) {
	    if (isset($values[$field_name]))
		$value = $values[$field_name];
	    else
		$value = $data["default_value"];

	    switch ($field_name) {
		case "action" :
		    if ($cant != 0) {
		        if ($edit) 
		    	    adm_table_cell(adm_form_submit(),"center",2);
			else
			    adm_standard_edit_delete(1,$values["id"]);
		    } else
		    	    adm_table_cell(
				adm_form_submit()."<br>".
				radiobutton("action",$GLOBALS["action_select"]["update"],"update")."Update",
		    		"center",2);
		    break;
    		
		case "id" :
		    if ($cant != 0) { 
			if ($edit)
			    adm_table_cell(checkbox_value("actionid[]",$value,1)." ".$value,"center");
			else {
			    if (in_array($value,$ids) or ($cant==1)) $check = 1; else $check=0;
			    adm_table_cell(checkbox_value("actionid[]",$value,$check). html_indenter()." ".$value);
		        }
		    } else
		    	adm_table_cell("<input type=checkbox onClick=\"this.value=check('actionid[]');\"> All<br>","center",1);

		    break;

		case "host":
		    if ($edit)
			adm_table_cell(select_hosts("host",$value));
		    else
			adm_table_cell($values["host_name"]." ".$values["zone_shortname"]);
		    break;

		case "type": 
		    if ($edit)
			adm_table_cell(select_interface_types($field_name,$value));
		    else
			adm_table_cell($values["type_description"]);
		    break;

		case "poll": 
		    if ($edit)
			adm_table_cell(select_pollers_groups($field_name,$value,$values["type"]),"center");
		    else
			adm_table_cell($values["poller_group_description"],"center");
		    break;

		case "interface": 
		    if ($edit)
			adm_table_cell(textbox($field_name,$value,20));
		    else
			adm_table_cell($values["interface"]);
		    break;

		case "client": 
		    if ($edit)
			adm_table_cell(select_clients($field_name,$value));
		    else
			adm_table_cell($values["client_name"]);
		    break;
		
		case "sla": 
		    if ($edit)
			adm_table_cell(select_slas($field_name,$value,$values["type"]),"center");
		    else
			adm_table_cell($values["sla_description"],"center");
		    break;
		
		case "check_status": 
		case "make_sound": 
		    if ($edit)
			adm_table_cell(checkbox($field_name,$value),"center");
		    else
			adm_table_cell(checkbox($field_name,$value,0),"center");
		    break;

		case "show_rootmap": 
		    adm_table_cell(select_show_rootmap($field_name,$value,!$edit),"center");
		    break;

    		case "row_filler":
		    $rows = $data["max"]-$number_of_showable_fields;
		    
		    if ($rows > 0)
		        adm_table_header_cell("&nbsp;","center",$rows);
		    break;
		
		case "poll_interval": 
		    if ($edit)
			adm_table_cell(select_poll_interval($field_name,$value),"center");
		    else
			adm_table_cell(select_poll_interval($field_name,$value,1),"center");
		    break;

		case "creation_date" :
		case "modification_date" :
		case "last_poll_date" :

		    if ($cant!=0)
			adm_table_cell(show_unix_date($values[$field_name]),"center");
		    else
		        adm_table_cell("&nbsp;");
			
		    break;
		    		
		default: 
		    switch ($data["type_handler"]) {

			case "bool" : //check box
			    if ($edit)
				adm_table_cell(checkbox($field_name,$value),"center");
			    else
				adm_table_cell(checkbox($field_name,$value,0),"center");
			    
			    break;
			    
			case "text" : //text is the pseudo-default
			default  :
			    if ($edit && ($data["overwritable"]==1))
				adm_table_cell(textbox($field_name,$value,20));
			    else 
				adm_table_cell($value,(is_numeric($value)?"right":""));
			    break;
		    }
	    }

	    if (($edit==1) && ($cant!=0) && ($data["overwritable"]==1)) //normal one interface edit
		echo hidden("update_fields[]",$field_name);

	}
    
    }

    function show_multiple_edit_boxes ($fields, $number_of_showable_fields) {
    	if (is_array($fields)) {
	    foreach ($fields as $field_name=>$data) if ($data["showable"] > 0)
		switch ($field_name) {
		    case "action" :
			adm_table_cell(radiobutton("action",$GLOBALS["action_select"]["delete"],"delete")."Delete","center",2);
			break;
			
		    case "id": 
		        adm_table_cell("Multiple<br>Edit","center",1);
			break;

		    case "row_filler":
			$rows = $data["max"]-$number_of_showable_fields;
		        if ($rows > 0)
			    adm_table_header_cell("&nbsp;","center",$rows);
			break;
		
		    case "creation_date" :
		    case "modification_date" :
		    case "last_poll_date" :
		        adm_table_cell("&nbsp;");
			break;
			
		    default:
			if ($data["overwritable"]==1)
			    adm_table_cell(checkbox_value("update_fields[]",$field_name,0),"center");
			else
		    	    adm_table_cell("&nbsp;");
		}
	}
    }
    
    $fields_init = array (
	"action"	=>array("description"=>"Action", 				"showable"=>1,	"overwritable"=>0),
	"id"		=>array("description"=>"ID", 					"showable"=>1,	"overwritable"=>0),
	"host"		=>array("description"=>"Host",		"default_value"=>1, 	"showable"=>1,	"overwritable"=>1),
	"type"		=>array("description"=>"Type", 		"default_value"=>1, 	"showable"=>0,	"overwritable"=>1),
	"interface"	=>array("description"=>"Interface Name", 			"showable"=>1,	"overwritable"=>1)
    );
    
    $fields_end = array (
	"row_filler"	=>array("description"=>"Row Filler", 				"showable"=>1,	"overwritable"=>0),
	"client"	=>array("description"=>"Customer", 	"default_value"=>1, 	"showable"=>1,	"overwritable"=>1),
	"poll"		=>array("description"=>"Poller Group", 	"default_value"=>1, 	"showable"=>1,	"overwritable"=>1),
	"check_status"	=>array("description"=>"Check Status", 	"default_value"=>1, 	"showable"=>1,	"overwritable"=>1),
	"sla"		=>array("description"=>"SLA", 		"default_value"=>1, 	"showable"=>1,	"overwritable"=>1),
	"make_sound"	=>array("description"=>"Enable Sound?", "default_value"=>0, 	"showable"=>1,	"overwritable"=>1),
	"show_rootmap"	=>array("description"=>"Show in Maps?", "default_value"=>0, 	"showable"=>1,	"overwritable"=>1),
	"poll_interval" =>array("description"=>"Polling Interval", "default_value"=>0, 	"showable"=>1,	"overwritable"=>1),
	"creation_date"	=>array("description"=>"Creation Date", 			"showable"=>1,	"overwritable"=>0),
	"modification_date"=>array("description"=>"Modification Date", 			"showable"=>1,	"overwritable"=>0),
	"last_poll_date"=>array("description"=>"Last Poll Date", 			"showable"=>1,	"overwritable"=>0)
    );	


    $api = $jffnms->get("interfaces");

    if (!$action)     $action_select["update"] = 1;
	else $action_select[$action] = 1;

    if (!$filter && $host_id) $filter = $host_id;

    if (!$add_to_map_id) $add_to_map_id = 1;
    
    if (!isset($actionid) && isset($interface_id)) $actionid = $interface_id; //for Manual Discovery filter and edit in one step
    if (!is_array($actionid)) $actionid=array("$actionid");

    if ($action=="add") {
	if (!$host_id) $host_id = 1; 

	$aux = $api->add($host_id);
	$actionid=array($aux);
	$interface_id = $aux;
	
	$action="edit";
	$old_action = "add";
    }

    if ($action=="update") {

	if (is_array($update_fields))
	    foreach ($update_fields as $field) 
		$data[$field]=$$field; 

	if (is_array($data) && (is_array($actionid))) 
	    foreach ($actionid as $id) 
		if (is_numeric($id)) 
		    $api->update($id,$data);

	$action="list";
    }

    if ($action=="bulkadd") {
	if (is_array($bulk_add_ids) && is_array($bulk_add)) { 
	    while (list($key,$data) = each ($bulk_add))
		if (in_array($key,$bulk_add_ids)) {
		    $aux_id = $api->add(array("host"=>$data["host"],"type"=>$data["type"])); //add
		    $result = $api->update($aux_id,$data); //update
		    $use_interfaces[]=$aux_id; //filter interfaces
		    $actionid[]=$aux_id; //mark interfaces
		}
	    if (count($bulk_add_ids)==1) 
		$action = "edit";
	    else
		$action = "list";
		
	    $action_select["update"]=1;
	    clean_url(array("use_interfaces"=>$use_interfaces),$clean_url_del_vars);
	    unset($bulk_add_ids);
	    unset($bulk_add);
	}
    }

    if ($action=="delete") {
	if (is_array($actionid)) 
	    foreach ($actionid as $id) 
		if (is_numeric($id)) 
		    $api->delete($id);
	$action="list";
    }

    if (($action=="map") && ($add_to_map_id > 1)) {
	$map = $jffnms->get("maps_interfaces");
	$map_list = $map->get_all($add_to_map_id);

	if (is_array($actionid)) 
	    foreach ($actionid as $id) 
		if (is_numeric($id)) {
		    $ok = 1;
		    foreach ($map_list as $aux) 
			if ($aux["interface"]==$id) $ok = 0; 

		    if ($ok==1) $map->add($add_to_map_id,$id);
		}
	unset($map);
	$action="list";
    }

    if (is_array($use_interfaces)) 
	if (!$_SERVER["QUERY_STRING"]) $interfaces_url = "&use_interfaces[]=".join("&use_interfaces[]=",$use_interfaces);

    $max_fields = 50;

    $filters = reports_make_interface_filter();
    $filters["with_field_type"] = 1;
    if (isset($filter)) $filters["host"] = $filter;
    $cant = $api->get($use_interfaces, $filters);

    adm_table_header("Interfaces",$init,&$span,$max_fields,$cant);

    if ($cant > 0) {
	$types_fields = $api->fetch();
	$cant--;

	foreach ($types_fields as $it=>$fds) 
	    foreach ($fds as $fd) if ($fd["showable"] > 0) $num_fields[$it]++;

	$fields_end["row_filler"]["max"] = (is_array($num_fields))?max($num_fields):0;
	
	unset ($it);
	unset ($fds);
	unset ($fd);
	
        $api->slice($init,$span);
	
	$old_interface_type = 0;
	$number_of_types = 0;
	
        adm_form("update");

        reports_pass_options();

	while ($register = $api->fetch()) {
	    table_shift_color($color);

	    if ($register["type"]!=$old_interface_type) {

		$type_fields = array_merge($fields_init,$types_fields[$register["type"]],$fields_end);
	
		show_header ($type_fields, $register,$num_fields[$register["type"]]);
	
		$old_interface_type = $register["type"];
		$number_of_types++;
	    }
	
	    if ((in_array($register["id"],$actionid)) && ($action=="edit")) 
		$edit = 1;
	    else 
		$edit = 0;

	    adm_table_row($color);

	    show_values ($type_fields,$register,$edit,$actionid,$cant,$num_fields[$register["type"]]);

	    adm_table_row_close();
	}
	
	if (($action!="edit") && ($cant > 1)) { //multiple editor
	    table_row("&nbsp;","center",$max_fields);
	    std_table_row($color);

	    if ($number_of_types > 1) {
		$multiple_edit_fields = array_merge($fields_init, $fields_end);
		unset ($old_interface_type); //to show all field types (sla, poll)
	    } else 
		$multiple_edit_fields = $type_fields;

	    show_values ($multiple_edit_fields,array("type"=>$old_interface_type),1,0,0,$num_fields[$old_interface_type]);

	    adm_table_row_close();
		    
	    std_table_row($color);
	    show_multiple_edit_boxes($multiple_edit_fields,$num_fields[$old_interface_type]);
	    adm_table_row_close();
	}
	
	if ($cant > 0) { //if theres an interface listed

	    if ($action!="edit") { //if we are in edit mode
	    
		std_table_row($color);
		if ($cant == 1) { //if the other option arent showing, show a Submit button
		    adm_table_cell(
			adm_form_submit("Add To Map")."<br>".
		        hidden("action","map"),
			"center",2);
		} else 
		    adm_table_cell(radiobutton("action",$action_select["map"],"map")."Add to Map:<br>","center",2);

		adm_table_cell(select_maps("add_to_map_id",$add_to_map_id),"center",2);
	        adm_table_cell(linktext("<small>View Map</small>","$jffnms_rel_path/admin/adm/adm_standard.php?admin_structure=maps_interfaces&filter=$add_to_map_id"),"",1);
		adm_table_cell("&nbsp;","",$max_fields-5);
		adm_table_row_close();
	    }
	
	    //Shortcuts
	    std_table_row($color);
	    adm_table_cell(linktext(adm_image("$jffnms_rel_path/images/graph.png","","",0,0,"Performance")." Performance","$jffnms_rel_path/view_performance.php?".$_SERVER[QUERY_STRING].$interfaces_url),"center",2);
	    adm_table_cell(linktext(adm_image("$jffnms_rel_path/images/text.png","","",0,0,"Report")." Report","$jffnms_rel_path/admin/reports/state_report.php?".$_SERVER[QUERY_STRING].$interfaces_url),"center",1);
	    adm_table_cell(linktext(adm_image("$jffnms_rel_path/images/text.png","","",0,0,"Alarms")." Alarms","$jffnms_rel_path/admin/adm/adm_alarms.php?".$_SERVER[QUERY_STRING].$interfaces_url),"center",1);

	    adm_table_cell("&nbsp;","",$max_fields-4);
	    adm_table_row_close();
	}
    } else 
	table_row("<br><b>No Records Found.</b>","center",$max_fields);
    
    adm_form_close();
    adm_footer();
?>

==> jffnms_0.7.9.orig.tar.gz: jffnms-0.7.9/htdocs/admin/adm/adm_interfaces.php <==
<? 
    $clean_url_del_vars=Array("bulk_add_ids","bulk_add");
    include ("../../auth.php");
    
    if (!profile("ADMIN_HOSTS")) die ("<H1> You dont have Permission to access this page.</H1></HTML>");

    adm_header("Interfaces");
?>
<SCRIPT>
function check(field_aux) {
    field=document.forms[0].elements[field_aux];
    for (i = 0; i < field.length; i++) { 
	if (field[i].checked==true) field[i].checked = false; 
	else	field[i].checked = true; 
    }
    return true;
}
</SCRIPT>
<?
    unset($old_action);


    function show_header($fields,$sample_data = array(),$number_of_showable_fields = 0) {
    
	std_table_row();

	if (is_array($fields))
	foreach ($fields as $field_name=>$data) 
	    if ($data["showable"] > 0)
		switch ($field_name) {
		    case "action" :
			if (is_numeric($GLOBALS["type_id"]))
			    adm_table_header_cell("<font size=-2>".linktext("View all Types",$GLOBALS["REQUEST_URI"]."&type_id=&action=")."</font>","center",2);
			else
			    adm_table_header_cell("<font size=-2>".linktext($sample_data["type_description"],$GLOBALS["REQUEST_URI"]."&action=&type_id=".$sample_data["type"])."</font>","center",2);
		        break;
    		    case "row_filler":
			$rows = $data["max"]-$number_of_showable_fields;
			if ($rows > 0)
			    adm_table_header_cell("&nbsp;","center",$rows);
			break;
		    default: 
			adm_table_header_cell($data["description"],"center");
		}

	adm_table_row_close();
    }

    function show_values ($fields,$values,$edit = 0, $ids = array(),$cant = 1, $number_of_showable_fields = 0) {
    
	if (is_array($fields))
	foreach ($fields as $field_name=>$data) if ($data["showable"] > 0) {
	    if (isset($values[$field_name]))
		$value = $values[$field_name];
	    else
		$value = $data["default_value"];

	    switch ($field_name) {
		case "action" :
		    if ($cant != 0) {
		        if ($edit) 
		    	    adm_table_cell(adm_form_submit(),"center",2);
			else
			    adm_standard_edit_delete(1,$values["id"]);
		    } else
		    	    adm_table_cell(
				adm_form_submit()."<br>".
				radiobutton("action",$GLOBALS["action_select"]["update"],"update")."Update",
		    		"center",2);
		    break;
    		
		case "id" :
		    if ($cant != 0) { 
			if ($edit)
			    adm_table_cell(checkbox_value("actionid[]",$value,1)." ".$value,"center");
			else {
			    if (in_array($value,$ids) or ($cant==1)) $check = 1; else $check=0;
			    adm_table_cell(checkbox_value("actionid[]",$value,$check). html_indenter()." ".$value);
		        }
		    } else
		    	adm_table_cell("<input type=checkbox onClick=\"this.value=check('actionid[]');\"> All<br>","center",1);

		    break;

		case "host":
		    if ($edit)
			adm_table_cell(select_hosts("host",$value));
		    else
			adm_table_cell($values["host_name"]." ".$values["zone_shortname"]);
		    break;

		case "type": 
		    if ($edit)
			adm_table_cell(select_interface_types($field_name,$value));
		    else
			adm_table_cell($values["type_description"]);
		    break;

		case "poll": 
		    if ($edit)
			adm_table_cell(select_pollers_groups($field_name,$value,$values["type"]),"center");
		    else
			adm_table_cell($values["poller_group_description"],"center");
		    break;

		case "interface": 
		    if ($edit)
			adm_table_cell(textbox($field_name,$value,20));
		    else
			adm_table_cell($values["interface"]);
		    break;

		case "client": 
		    if ($edit)
			adm_table_cell(select_clients($field_name,$value));
		    else
			adm_table_cell($values["client_name"]);
		    break;
		
		case "sla": 
		    if ($edit)
			adm_table_cell(select_slas($field_name,$value,$values["type"]),"center");
		    else
			adm_table_cell($values["sla_description"],"center");
		    break;
		
		case "check_status": 
		case "make_sound": 
		    if ($edit)
			adm_table_cell(checkbox($field_name,$value),"center");
		    else
			adm_table_cell(checkbox($field_name,$value,0),"center");
		    break;

		case "show_rootmap": 
		    adm_table_cell(select_show_rootmap($field_name,$value,!$edit),"center");
		    break;

    		case "row_filler":
		    $rows = $data["max"]-$number_of_showable_fields;
		    
		    if ($rows > 0)
		        adm_table_header_cell("&nbsp;","center",$rows);
		    break;
		
		case "poll_interval": 
		    if ($edit)
			adm_table_cell(select_poll_interval($field_name,$value),"center");
		    else
			adm_table_cell(select_poll_interval($field_name,$value,1),"center");
		    break;

		case "creation_date" :
		case "modification_date" :
		case "last_poll_date" :

		    if ($cant!=0)
			adm_table_cell(show_unix_date($values[$field_name]),"center");
		    else
		        adm_table_cell("&nbsp;");
			
		    break;
		    		
		default: 
		    switch ($data["type_handler"]) {

			case "bool" : //check box
			    if ($edit)
				adm_table_cell(checkbox($field_name,$value),"center");
			    else
				adm_table_cell(checkbox($field_name,$value,0),"center");
			    
			    break;
			    
			case "text" : //text is the pseudo-default
			default  :
			    if ($edit && ($data["overwritable"]==1))
				adm_table_cell(textbox($field_name,$value,20));
			    else 
				adm_table_cell($value,(is_numeric($value)?"right":""));
			    break;
		    }
	    }

	    if (($edit==1) && ($cant!=0) && ($data["overwritable"]==1)) //normal one interface edit
		echo hidden("update_fields[]",$field_name);

	}
    
    }

    function show_multiple_edit_boxes ($fields, $number_of_showable_fields) {
    	if (is_array($fields)) {
	    foreach ($fields as $field_name=>$data) if ($data["showable"] > 0)
		switch ($field_name) {
		    case "action" :
			adm_table_cell(radiobutton("action",$GLOBALS["action_select"]["delete"],"delete")."Delete","center",2);
			break;
			
		    case "id": 
		        adm_table_cell("Multiple<br>Edit","center",1);
			break;

		    case "row_filler":
			$rows = $data["max"]-$number_of_showable_fields;
		        if ($rows > 0)
			    adm_table_header_cell("&nbsp;","center",$rows);
			break;
		
		    case "creation_date" :
		    case "modification_date" :
		    case "last_poll_date" :
		        adm_table_cell("&nbsp;");
			break;
			
		    default:
			if ($data["overwritable"]==1)
			    adm_table_cell(checkbox_value("update_fields[]",$field_name,0),"center");
			else
		    	    adm_table_cell("&nbsp;");
		}
	}
    }
    
    $fields_init = array (
	"action"	=>array("description"=>"Action", 				"showable"=>1,	"overwritable"=>0),
	"id"		=>array("description"=>"ID", 					"showable"=>1,	"overwritable"=>0),
	"host"		=>array("description"=>"Host",		"default_value"=>1, 	"showable"=>1,	"overwritable"=>1),
	"type"		=>array("description"=>"Type", 		"default_value"=>1, 	"showable"=>0,	"overwritable"=>1),
	"interface"	=>array("description"=>"Interface Name", 			"showable"=>1,	"overwritable"=>1)
    );
    
    $fields_end = array (
	"row_filler"	=>array("description"=>"Row Filler", 				"showable"=>1,	"overwritable"=>0),
	"client"	=>array("description"=>"Customer", 	"default_value"=>1, 	"showable"=>1,	"overwritable"=>1),
	"poll"		=>array("description"=>"Poller Group", 	"default_value"=>1, 	"showable"=>1,	"overwritable"=>1),
	"check_status"	=>array("description"=>"Check Status", 	"default_value"=>1, 	"showable"=>1,	"overwritable"=>1),
	"sla"		=>array("description"=>"SLA", 		"default_value"=>1, 	"showable"=>1,	"overwritable"=>1),
	"make_sound"	=>array("description"=>"Enable Sound?", "default_value"=>0, 	"showable"=>1,	"overwritable"=>1),
	"show_rootmap"	=>array("description"=>"Show in Maps?", "default_value"=>0, 	"showable"=>1,	"overwritable"=>1),
	"poll_interval" =>array("description"=>"Polling Interval", "default_value"=>0, 	"showable"=>1,	"overwritable"=>1),
	"creation_date"	=>array("description"=>"Creation Date", 			"showable"=>1,	"overwritable"=>0),
	"modification_date"=>array("description"=>"Modification Date", 			"showable"=>1,	"overwritable"=>0),
	"last_poll_date"=>array("description"=>"Last Poll Date", 			"showable"=>1,	"overwritable"=>0)
    );	


    $api = $jffnms->get("interfaces");

    if (!$action)     $action_select["update"] = 1;
	else $action_select[$action] = 1;

    if (!$filter && $host_id) $filter = $host_id;

    if (!$add_to_map_id) $add_to_map_id = 1;
    
    if (!isset($actionid) && isset($interface_id)) $actionid = $interface_id; //for Manual Discovery filter and edit in one step
    if (!is_array($actionid)) $actionid=array("$actionid");

    if ($action=="add") {
	if (!$host_id) $host_id = 1; 

	$aux = $api->add($host_id);
	$actionid=array($aux);
	$interface_id = $aux;
	
	$action="edit";
	$old_action = "add";
    }

    if ($action=="update") {

	if (is_array($update_fields))
	    foreach ($update_fields as $field) 
		$data[$field]=trim($$field); 

	if (is_array($data) && (is_array($actionid))) 
	    foreach ($actionid as $id) 
		if (is_numeric($id)) 
		    $api->update($id,$data);

	$action="list";
    }

    if ($action=="bulkadd") {
	if (is_array($bulk_add_ids) && is_array($bulk_add)) { 
	    while (list($key,$data) = each ($bulk_add))
		if (in_array($key,$bulk_add_ids)) {
		    $aux_id = $api->add(array("host"=>$data["host"],"type"=>$data["type"])); //add
		    $result = $api->update($aux_id,$data); //update
		    $use_interfaces[]=$aux_id; //filter interfaces
		    $actionid[]=$aux_id; //mark interfaces
		}
	    if (count($bulk_add_ids)==1) 
		$action = "edit";
	    else
		$action = "list";
		
	    $action_select["update"]=1;
	    clean_url(array("use_interfaces"=>$use_interfaces),$clean_url_del_vars);
	    unset($bulk_add_ids);
	    unset($bulk_add);
	}
    }

    if ($action=="delete") {
	if (is_array($actionid)) 
	    foreach ($actionid as $id) 
		if (is_numeric($id)) 
		    $api->delete($id);
	$action="list";
    }

    if (($action=="map") && ($add_to_map_id > 1)) {
	$map = $jffnms->get("maps_interfaces");
	$map_list = $map->get_all($add_to_map_id);

	if (is_array($actionid)) 
	    foreach ($actionid as $id) 
		if (is_numeric($id)) {
		    $ok = 1;
		    foreach ($map_list as $aux) 
			if ($aux["interface"]==$id) $ok = 0; 

		    if ($ok==1) $map->add($add_to_map_id,$id);
		}
	unset($map);
	$action="list";
    }

    if (is_array($use_interfaces)) 
	if (!$_SERVER["QUERY_STRING"]) $interfaces_url = "&use_interfaces[]=".join("&use_interfaces[]=",$use_interfaces);

    $max_fields = 50;

    $filters = reports_make_interface_filter();
    $filters["with_field_type"] = 1;
    if (isset($filter)) $filters["host"] = $filter;
    $cant = $api->get($use_interfaces, $filters);

    adm_table_header("Interfaces",$init,&$span,$max_fields,$cant);

    if ($cant > 0) {
	$types_fields = $api->fetch();
	$cant--;

	foreach ($types_fields as $it=>$fds) 
	    foreach ($fds as $fd) if ($fd["showable"] > 0) $num_fields[$it]++;

	$fields_end["row_filler"]["max"] = (is_array($num_fields))?max($num_fields):0;
	
	unset ($it);
	unset ($fds);
	unset ($fd);
	
        $api->slice($init,$span);
	
	$old_interface_type = 0;
	$number_of_types = 0;
	
        adm_form("update");

        reports_pass_options();

	while ($register = $api->fetch()) {
	    table_shift_color($color);

	    if ($register["type"]!=$old_interface_type) {

		$type_fields = array_merge($fields_init,$types_fields[$register["type"]],$fields_end);
	
		show_header ($type_fields, $register,$num_fields[$register["type"]]);
	
		$old_interface_type = $register["type"];
		$number_of_types++;
	    }
	
	    if ((in_array($register["id"],$actionid)) && ($action=="edit")) 
		$edit = 1;
	    else 
		$edit = 0;

	    adm_table_row($color);

	    show_values ($type_fields,$register,$edit,$actionid,$cant,$num_fields[$register["type"]]);

	    adm_table_row_close();
	}
	
	if (($action!="edit") && ($cant > 1)) { //multiple editor
	    table_row("&nbsp;","center",$max_fields);
	    std_table_row($color);

	    if ($number_of_types > 1) {
		$multiple_edit_fields = array_merge($fields_init, $fields_end);
		unset ($old_interface_type); //to show all field types (sla, poll)
	    } else 
		$multiple_edit_fields = $type_fields;

	    show_values ($multiple_edit_fields,array("type"=>$old_interface_type),1,0,0,$num_fields[$old_interface_type]);

	    adm_table_row_close();
		    
	    std_table_row($color);
	    show_multiple_edit_boxes($multiple_edit_fields,$num_fields[$old_interface_type]);
	    adm_table_row_close();
	}
	
	if ($cant > 0) { //if theres an interface listed

	    if ($action!="edit") { //if we are in edit mode
	    
		std_table_row($color);
		if ($cant == 1) { //if the other option arent showing, show a Submit button
		    adm_table_cell(
			adm_form_submit("Add To Map")."<br>".
		        hidden("action","map"),
			"center",2);
		} else 
		    adm_table_cell(radiobutton("action",$action_select["map"],"map")."Add to Map:<br>","center",2);

		adm_table_cell(select_maps("add_to_map_id",$add_to_map_id),"center",2);
	        adm_table_cell(linktext("<small>View Map</small>","$jffnms_rel_path/admin/adm/adm_standard.php?admin_structure=maps_interfaces&filter=$add_to_map_id"),"",1);
		adm_table_cell("&nbsp;","",$max_fields-5);
		adm_table_row_close();
	    }
	
	    //Shortcuts
	    std_table_row($color);
	    adm_table_cell(linktext(adm_image("$jffnms_rel_path/images/graph.png","","",0,0,"Performance")." Performance","$jffnms_rel_path/view_performance.php?".$_SERVER["QUERY_STRING"].$interfaces_url),"center",2);
	    adm_table_cell(linktext(adm_image("$jffnms_rel_path/images/text.png","","",0,0,"Report")." Report","$jffnms_rel_path/admin/reports/state_report.php?".$_SERVER["QUERY_STRING"].$interfaces_url),"center",1);
	    adm_table_cell(linktext(adm_image("$jffnms_rel_path/images/text.png","","",0,0,"Alarms")." Alarms","$jffnms_rel_path/admin/adm/adm_alarms.php?".$_SERVER["QUERY_STRING"].$interfaces_url),"center",1);

	    adm_table_cell("&nbsp;","",$max_fields-4);
	    adm_table_row_close();
	}
    } else 
	table_row("<br><b>No Records Found.</b>","center",$max_fields);
    
    adm_form_close();
    adm_footer();
?>
